import {httpGet,httpPost} from "@/utils/request.js"


/**
 * 微信登录
 * @param code 微信code 
 */
export const apiWechatLogin=params=>{
	return httpGet('/wechat/login',params)
}

/**
 * 顶部tab
 */
export const apiHomeTab = () => {
	return httpGet('/user/get_top_tab')
}

/**
 * 获取用户tabbar权限
 */
export const apiUserTabBar=()=>{
	return httpGet('/user/get_tab_bar',{})
}

/**
 * 获取个人信息
 */
export const apiUserInfo=()=>{
	return httpGet('/user/info',{})
}

/**
 * 手机号/邮箱登录
 * @param area_num 手机号区号
 * @param bind_type 1手机号 2邮箱
 * @param email
 * @param mobile
 * @param verify_code
 */
export const apiUserLogin=params=>{
	return httpPost('/user/login',params)
}

/**
 * 用户权限申请
 * @param business_card_url 名片地址
 * @param company_name 公司名
 * @param permission 选择的权限
 * @param real_name 姓名
 * @param source 来源：我的1、活动2、图库3、研报4、问答社区5、价格驱动6、沙盘推演7、语音播报8、视频社区9、线上路演10
 * @param source_agent 来源平台：1:小程序、2:小程序(pc)、3:公众号、4:官网web(pc)
 * @param from_page 来源页面: '活动列表'、'活动详情'等
 */
export const apiApplyPermission=params=>{
	return httpPost('/user/apply',{...params,source_agent:1})
}

/**
 * 获取用户最近一条申请单信息
 */
export const apiLastApplyRecord=(params)=>{
	return httpGet('/user/get_last_apply_record',params)
}


/**
 * 个人设置 头像/昵称  nick_name head_img_url
 */
export const apiSetMyinfo = params => {
	return httpPost('/user/set',params)
}

/**
 * 收藏
 * @param collection_type 收藏类型：1-研报; 2-视频社区; 3-微路演视频
 * @param primary_id //收藏类型主ID(如报告id,视频id)
 * @param extend_id //扩展ID-如研报章节ID
 * @param source_agent //操作来源：1-小程序 2-小程序 PC 3-弘则研究公众号 4-Web PC
 */
export const apiSetCollect=params=>{
	return httpPost('/collection/collect',{source_agent:1,...params})
}

/**
 * 取消收藏
 * @param collection_id 收藏ID
 */
export const apiCancelCollect=params=>{
	return httpPost('/collection/cancel',params)
}

/**
 * 我的收藏列表
 * @param curr_page
 * @param page_size
 * @param keywords
 * @param from_type 来源类型：0-全部; 1-研报; 2-线上路演; 3-视频社区
 */
export const apiMyCollectList=params=>{
	return httpGet('/collection/list',params)
}